@@ -39,14 +39,48 @@ const nsISupports              = Components.interfaces.nsISupports;
 
 const nsICommandLine           = Components.interfaces.nsICommandLine;
 const nsICommandLineHandler    = Components.interfaces.nsICommandLineHandler;
+const nsICommandLineValidator  = Components.interfaces.nsICommandLineValidator;
 const nsIDOMWindowInternal     = Components.interfaces.nsIDOMWindowInternal;
 const nsIFactory               = Components.interfaces.nsIFactory;
+const nsIFileURL               = Components.interfaces.nsIFileURL;
+const nsIJARURI                = Components.interfaces.nsIJARURI;
 const nsISupportsString        = Components.interfaces.nsISupportsString;
 const nsIWindowMediator        = Components.interfaces.nsIWindowMediator;
 const nsIWindowWatcher         = Components.interfaces.nsIWindowWatcher;
 
 const NS_ERROR_ABORT = Components.results.NS_ERROR_ABORT;
 
+function resolveURIInternal(aCmdLine, aArgument) {
+  var uri = aCmdLine.resolveURI(aArgument);
+
+  if (!(uri instanceof nsIFileURL)) {
+    return uri;
+  }
+
+  try {
+    if (uri.file.exists())
+      return uri;
+  }
+  catch (e) {
+    Components.utils.reportError(e);
+  }
+
+  // We have interpreted the argument as a relative file URI, but the file
+  // doesn't exist. Try URI fixup heuristics: see bug 290782.
+ 
+  try {
+    var urifixup = Components.classes["@mozilla.org/docshell/urifixup;1"]
+                             .getService(nsIURIFixup);
+
+    uri = urifixup.createFixupURI(aArgument, 0);
+  }
+  catch (e) {
+    Components.utils.reportError(e);
+  }
+
+  return uri;
+}
+
 function mayOpenURI(uri)
 {
   var ext = Components.classes["@mozilla.org/uriloader/external-protocol-service;1"]
@@ -87,6 +121,7 @@ var nsMailDefaultHandler = {
 
   QueryInterface : function mdh_QI(iid) {
     if (iid.equals(nsICommandLineHandler) ||
+        iid.equals(nsICommandLineValidator) ||
         iid.equals(nsIFactory) ||
         iid.equals(nsISupports))
       return this;
@@ -128,7 +163,7 @@ var nsMailDefaultHandler = {
           switch (remoteParams[0].toLowerCase()) {
           case "openinbox":
             var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
-                               .getService(Components.classes.nsIWindowMediator);
+                               .getService(nsIWindowMediator);
             var win = wm.getMostRecentWindow("mail:3pane");
             if (win) {
               win.focus();
@@ -186,11 +221,31 @@ var nsMailDefaultHandler = {
                              .getService(nsIWindowWatcher);
       var argstring = Components.classes["@mozilla.org/supports-string;1"]
                                 .createInstance(nsISupportsString);
-      wwatch.openWindow(null, chromeParam, "_blank",
-                        "chrome,dialog=no,all", argstring);
-      cmdLine.preventDefault = true;
+
+      try {
+        // only load URIs which do not inherit chrome privs.
+
+        // normally would call checkLoadURI( ,DISALLOW_SCRIPT_OR_DATA)
+        // for this, but in this context we crash when the security manager
+        // tries to throw an exception (no window object here). On the branch
+        // we need to simulate the important bits
+        var uri = resolveURIInternal(cmdLine, chromeParam);
+        while (uri instanceof nsIJARURI) {
+          // unpack to find the real scheme
+          uri = uri.JARFile;
+        }
+        if (!uri.schemeIs("javascript") && !uri.schemeIs("data")) {
+          wwatch.openWindow(null, uri.spec, "_blank",
+                            "chrome,dialog=no,all", argstring);
+          cmdLine.preventDefault = true;
+        }
+      }
+      catch (e) {
+        dump(e);
+        throw Components.results.NS_ERROR_ABORT;
+      }
     }
-    
+
     var count = cmdLine.length;
     if (count) {
       var i = 0;
@@ -274,6 +329,30 @@ var nsMailDefaultHandler = {
                       "chrome,dialog=no,all", argstring);
   },
 
+  /* nsICommandLineValidator */
+  validate : function mdh_validate(cmdLine) {
+    // Other handlers may use osint so only handle the osint flag if the mail
+    // or compose flag is also present and the command line is valid.
+    var osintFlagIdx = cmdLine.findFlag("osint", false);
+    var mailFlagIdx = cmdLine.findFlag("mail", false);
+    var composeFlagIdx = cmdLine.findFlag("compose", false);
+
+    // If both flags are present use the first flag found so the command line
+    // length test will fail.
+    if (mailFlagIdx > -1 && composeFlagIdx > -1)
+      var actionFlagIdx = mailFlagIdx > composeFlagIdx ? composeFlagIdx : mailFlagIdx;
+    else
+      actionFlagIdx = mailFlagIdx > -1 ? mailFlagIdx : composeFlagIdx;
+
+    if (actionFlagIdx && (osintFlagIdx > -1)) {
+      var param = cmdLine.getArgument(actionFlagIdx + 1);
+      if (cmdLine.length != actionFlagIdx + 2 ||
+          /thunderbird.url.(mailto|news):/.test(param))
+        throw NS_ERROR_ABORT;
+      cmdLine.handleFlag("osint", false)
+    }
+  },
+
   helpInfo : "",
 
   /* nsIFactory */
@@ -329,6 +408,9 @@ var Module = {
     catMan.addCategoryEntry("command-line-handler",
                             "x-default",
                             mdh_contractID, true, true);
+    catMan.addCategoryEntry("command-line-validator",
+                            "b-default",
+                            mdh_contractID, true, true);
   },
     
   unregisterSelf : function mod_unregself(compMgr, location, type) {
@@ -339,7 +421,9 @@ var Module = {
                            .getService(Components.interfaces.nsICategoryManager);
 
     catMan.deleteCategoryEntry("command-line-handler",
-                               "y-default", true);
+                               "x-default", true);
+    catMan.deleteCategoryEntry("command-line-validator",
+                               "b-default", true);
   },
 
   canUnload: function(compMgr) {
