@@ -66,6 +66,7 @@ pref("editor.table.maintain_structure", true);
 pref("editor.prettyprint", true);
 
 pref("editor.throbber.url","chrome://editor-region/locale/region.properties");
+pref("editor.spellcheckers.url","chrome://editor-region/locale/region.properties");
 
 pref("editor.toolbars.showbutton.new", true);
 pref("editor.toolbars.showbutton.open", true);
@@ -128,9 +129,9 @@ pref("editor.always_show_publish_dialog",    false);
  */
 //pref("editor.encode_entity",                 "html");
 
-//@line 133 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/editor/ui/composer.js"
+//@line 134 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/editor/ui/composer.js"
 pref("editor.disable_spell_checker", false);
 pref("editor.dont_lock_spell_files", true);
-//@line 137 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/editor/ui/composer.js"
+//@line 138 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/editor/ui/composer.js"
 
 pref("editor.CR_creates_new_p",      false);
