@@ -1,4 +1,4 @@
-//@line 40 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/components/viewconfig/content/config.js"
+//@line 40 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/components/viewconfig/content/config.js"
 
 const nsIPrefLocalizedString = Components.interfaces.nsIPrefLocalizedString;
 const nsISupportsString = Components.interfaces.nsISupportsString;
@@ -274,7 +274,6 @@ function onConfigLoad()
 {
   // Load strings
   gConfigBundle = document.getElementById("configBundle");
-  document.title = gConfigBundle.getString("title");
 
   gLockStrs[PREF_IS_DEFAULT_VALUE] = gConfigBundle.getString("default");
   gLockStrs[PREF_IS_USER_SET] = gConfigBundle.getString("user");
