@@ -1,4 +1,4 @@
-//@line 42 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/downloads/content/downloads.js"
+//@line 42 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/downloads/content/downloads.js"
 
 ///////////////////////////////////////////////////////////////////////////////
 // Globals
@@ -718,20 +718,6 @@ var gDownloadViewController = {
   }
 };
 
-function onDownloadShowOptions()
-{
-  var windowManager = Components.classes['@mozilla.org/appshell/window-mediator;1'].getService();
-  var windowManagerInterface = windowManager.QueryInterface(Components.interfaces.nsIWindowMediator);
-  var topWindow = windowManagerInterface.getMostRecentWindow("Browser:Options");
-  if (topWindow) {
-    topWindow.focus();
-    topWindow.switchPage("catDownloadsButton");
-  }
-  else
-    openDialog("chrome://browser/content/pref/pref.xul", "PrefWindow",
-              "chrome,titlebar,resizable,modal", "catDownloadsButton");
-}
-
 function onDownloadShowInfo()
 {
   if (gDownloadsView.selectedItem)
@@ -758,9 +744,9 @@ function initAutoDownloadDisplay()
     if (aFolderType != "Downloads")
       throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
 
-//@line 807 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/downloads/content/downloads.js"
+//@line 793 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/downloads/content/downloads.js"
     return "Home";
-//@line 810 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/downloads/content/downloads.js"
+//@line 796 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/mozapps/downloads/content/downloads.js"
     }
     
     function getDownloadsFolder(aFolder)
